*******************************************************************
* weaponsregs.do
*******************************************************************
* Regressions for "Detecting illegal arms trades" paper
*******************************************************************

clear
set mem 385m
set matsize 1000
set more off
cd "c:/Users/sdellavi/My Documents/Brief/Research/weapons/AEJDataPosting"
cap log close
log using regs/weaponsregs, replace


*********************************************************************************************
***************************************** T A B L E S ***************************************
*********************************************************************************************

**** Compute probabilities of switching for calibration
insheet using ./data/TransProb.csv,clear
* Notice that in 1999 there are two events in Sierra Leone:
* one increasing hostilities, the other decreasing hostilities. 
* Given the linear estimation assumption, we code 1999 as a year with no events
reshape long emb eve evn, i(country) j(year)
rename emb embargo
recode eve .=0
recode evn .=0
sort country year
* Generate lagged values
foreach x in embargo eve evn {
	gen `x'm1 = `x'[_n-1] if country==country[_n-1]
	}
* Embargo probabilities as a function of previous embargo state
bys embargom1: su embargo
* Embargo probabilities as a function of events in previous year
bys evem1: su embargo if (embargom1==1|abs(evem1)==1)
bys evnm1: su embargo if (embargom1==0|abs(evnm1)==1)
* Probit specification for effect of conflict events on Embargo probabilities
dprobit embargo evem1 if (embargom1==1|abs(evem1)==1)
dprobit embargo evnm1 if (embargom1==0|abs(evnm1)==1)


***** Do the main regressions
use regs/weaponsregsAEJ,clear
drop day month unembargo samplenowest retri retli eretri ev*s2noemb* ev*s3noemb* evsneemb* /*
*/ *usd* evs evs2 evs3 evl evsne pressfrav cpiav nodeal transp cpi pressfr bpi06 corrk /*
*/ evl*noemb* *unexplx* *implx* evs2*tr* evs3*tr* evl*tr* hits* evsembm3-evsembp200 aretrim* aretrip*
replace descr=abbrev(descr,12)
replace descr="" if evsemb==0
cd output/TablesAEJOct10
compress
memory
* 121m


********** List all events to be sure -- Here this is tricky because events fall on different days for Asian and non-Asian companies
sort date
* Inside embargo -- Standard Definition
list year date country evsemb evsnoemb if date~=date[_n-1] & abs(evsemb)==1
* Inside embargo -- Broad Definition
list year date country evsemb evsnoemb evlemb if date~=date[_n-1] & abs(evlemb)==1
* Inside embargo -- Mechanical Definition
list year date country evsemb evsnoemb evlemb evs2emb if date~=date[_n-1] & abs(evs2emb)==1
* Outside embargo -- Standard Definition
list year date country evsemb evsnoemb if date~=date[_n-1] & abs(evsnoemb)==1
* Outside embargo -- Other Countries
list year date country evsemb evsnenoemb if date~=date[_n-1] & abs(evsnenoemb)==1


********************* FIGURES 1A AND 1B *********************************************
* Generate a sample of all events not during the embargo, including the ones in countries with no embargo
gen evsnoemball=evsnoemb
replace evsnoemball=evsnenoemb if evsnenoemb~=0
gen evsnoemballd2cpi=evsnoemball*d2cpi
gen evsnoemballd2nocpi=evsnoemball*(1-d2cpi)
foreach x in evsemb evsembd2cpi evsembd2nocpi evsnoemball evsnoemballd2cpi evsnoemballd2nocpi {
	gen dp1`x'=(`x'==1) if `x'~=.
	gen dm1`x'=(`x'==-1) if `x'~=.
	}
foreach x in evsemb evsnoemball {
	gen d0`x'=(`x'==0) if `x'~=.
	gen d0`x'd2cpi=(`x'==0 & d2cpi==1) if `x'~=.
	gen d0`x'd2nocpi=(`x'==0 & d2cpi==0) if `x'~=.
	}
bys d2cpi evsemb: su aret3ri
xi: reg aret3ri dm1evsembd2nocpi d0evsembd2nocpi dp1evsembd2nocpi dm1evsembd2cpi d0evsembd2cpi dp1evsembd2cpi, nocons robust cluster(date)
outreg using Figure1, ctitle() se 3aster bdec(4) rdec(4) replace
xi: reg aret3ri dm1evsnoemballd2nocpi d0evsnoemballd2nocpi dp1evsnoemballd2nocpi dm1evsnoemballd2cpi d0evsnoemballd2cpi dp1evsnoemballd2cpi, nocons robust cluster(date)
outreg using Figure1, ctitle() se 3aster bdec(4) rdec(4) append


********************* FIGURE 2 -- EVENT BY EVENT ********************************************
* Notice that when the event falls on a weekend we measure returns the next trading day
local j=1
foreach i in "10,4,1993" "4,29,1996" "9,21,1998" "12,14,1998" "1,6,1999" "8,10,1999" "12,13,1999" "6,5,2003" {
	gen dpos`j'nocpi=(date==mdy(`i'))*d2nocpi
	gen dpos`j'cpi=(date==mdy(`i'))*d2cpi
	local j=`j'+1
	}
local j=1
foreach i in "7,4,1994" "8,2,1996" "3,10,1998" "5,18,1999" "9,28,1999" "5,17,2000" "12,12,2000" "3,30,2001" "2,22,2002" "8,1,2005" {
	gen dneg`j'nocpi=(date==mdy(`i'))*d2nocpi
	gen dneg`j'cpi=(date==mdy(`i'))*d2cpi
	local j=`j'+1
	}
reg aret3ri dpos* dneg* if sample1==1, nocons robust
outreg using Figure2, ctitle(event-by-event, nocons) se 3aster bdec(4) rdec(4) replace
display binomialtail(18,14,.5)
display binomialtail(18,13,.5)
drop dpos* dneg*


*********** WEB APPENDIX TABLE 3 -- LIST OF COUNTRIES **********************************
egen tagcomp=tag(compname)
replace tagcomp=. if tagcomp==0
bys market: egen countcomp=count(tagcomp)
*& s2cpi, s2transp, s2 pressfr, s2 bpi06, s2nodeal
foreach x in cpi transp pressfr bpi06 nodeal {
	gen s2`x'="Yes" if d2`x'==1
	replace s2`x'="No" if d2`x'==0
	}
gsort now -countcomp market
list now market countcomp s2cpi s2transp s2pressfr s2bpi06 s2nodeal if market~=market[_n+1], clean


********************* WEB APPENDIX TABLE 4 -- LIST OF COMPANIES ************************************
bys compnamelong: egen count=count(aret3ri)
gsort now -countcomp market compnamelong date
* sort market compnamelong date
gen ssipricomp="S" if dsipri==1 & dwscope==0
replace ssipricomp="W" if dsipri==0 & dwscope==1
replace ssipricomp="WS" if dsipri==1 & dwscope==1
list compnamelong market count ssipricomp if compnamelong~=compnamelong[_n-1], clean

*** Drop variables we use no more
drop ssipricomp compnamelong listing count* tag* country


******** TABLE 1 -- BENCHMARK TABLE *************************
* Benchmark Spec. -- Interact with Corruption Index
xi: reg aret3ri evsemb evsembd2cpi d2cpi if sample1==1, robust cluster(date)
outreg evsemb evsembd2cpi d2cpi using Table1, title(Table Main) ctitle(ab3,s1,clcomp) se 3aster bdec(4) rdec(4) replace
* Do only for events
xi: reg aret3ri evsemb evsembd2cpi if sample1==1 & abs(evsemb)==1, nocons robust cluster(date)
outreg using Table1, ctitle(onlyev,s1,clcomp) se 3aster bdec(4) rdec(4) append
* Do for Corrupt and non-Corrupt
xi: reg aret3ri evsembd2cpi evsembd2nocpi d2cpi if sample1==1, robust cluster(date)
outreg using Table1, ctitle(corr-nonc,s1,clcomp) se 3aster bdec(4) rdec(4) append


******** WEB APPENDIX TABLE 5 -- ROBUSTNESS TABLE *************************
* Interact with Corruption Index and ln GDP
xi: reg aret3ri evsemb evsembd2cpi evsemblngdp d2cpi lngdp if sample1==1, robust cluster(date)
outreg evsemb evsembd2cpi evsemblngdp d2cpi lngdp using WebTable5, ctitle(ab3,s1,clcomp) se 3aster bdec(4) rdec(4) replace
* Shift time difference
* Other clustering
xi: reg aret3ri evsemb evsembd2cpi d2cpi if sample1==1, robust cluster(compname)
outreg evsemb evsembd2cpi d2cpi using WebTable5, ctitle(ab3,s1,cldate) se 3aster bdec(4) rdec(4) append
* Non-Stale
xi: reg aret3ri evsemb evsembd2cpi d2cpi if sample1==1 & dstalecompyr==0, robust cluster(date)
outreg evsemb evsembd2cpi d2cpi using WebTable5, ctitle(ab3,Non-Stale) se 3aster bdec(4) rdec(4) append
* Do (0,1) result
xi: reg aret2ri evsemb evsembd2cpi d2cpi if sample1==1, robust cluster(date)
outreg evsemb evsembd2cpi d2cpi using WebTable5, ctitle(ab2,s1,clcomp) se 3aster bdec(4) rdec(4) append
* Raw returns
xi: reg ret3ri evsemb evsembd2cpi d2cpi if sample1==1 & aret3ri~=., robust cluster(date)
outreg evsemb evsembd2cpi d2cpi using WebTable5, ctitle(raw3,s1,clcomp) se 3aster bdec(4) rdec(4) append
* Net returns
xi: reg eret3ri evsemb evsembd2cpi d2cpi if sample1==1 & aret3ri~=., robust cluster(date)
outreg evsemb evsembd2cpi d2cpi using WebTable5, ctitle(exc3,s1,clcomp) se 3aster bdec(4) rdec(4) append


******** TABLE 2 -- VARIOUS MEASURES OF COST OF ILLEGAL TRADES
** PANEL A
* Interact with Corruption Index
xi: reg aret3ri evsemb evsembd2cpi d2cpi if sample1==1, robust cluster(date)
outreg evsemb evsembd2cpi d2cpi using Table2, title (Table Other Measures of Cost of Illegal Trades) ctitle(ab3,s1,clcomp) se 3aster bdec(4) rdec(4) replace
* Interact with Corruption according to Kaufman
xi: reg aret3ri evsemb evsembd2corrk d2corrk if sample1==1, robust cluster(date)
outreg evsemb evsembd2corrk d2corrk using Table2, ctitle(ab3,s1,clcomp) se 3aster bdec(4) rdec(4) append
* Interact with Transparency Index
xi: reg aret3ri evsemb evsembd2transp d2transp if sample1==1, robust cluster(date)
outreg using Table2, ctitle(ab3,s1,clcomp) se 3aster bdec(4) rdec(4) append
* Interact with Western company
xi: reg aret3ri evsemb evsembnow now if sample1==1, robust cluster(date)
outreg evsemb evsembnow now using Table2, ctitle(ab3,s1,clcomp) se 3aster bdec(4) rdec(4) append
* Interact with Press Freedom
xi: reg aret3ri evsemb evsembd2pressfr d2pressfr if sample1==1, robust cluster(date)
outreg evsemb evsembd2pressfr d2pressfr using Table2, ctitle(ab3,s1,clcomp) se 3aster bdec(4) rdec(4) append
* Interact with Bribepayer
xi: reg aret3ri evsemb evsembd2bpi06 d2bpi06 if sample1==1, robust cluster(date)
outreg using Table2, ctitle(ab3,s1,clcomp) se 3aster bdec(4) rdec(4) append
* Interact with Self-Dealing Index
xi: reg aret3ri evsemb evsembd2nodeal d2nodeal if sample1==1, robust cluster(date)
outreg evsemb evsembd2nodeal d2nodeal using Table2, ctitle(ab3,s1,clcomp) se 3aster bdec(4) rdec(4) append
** PANEL B. Continuous variables
* Interact with Corruption Variable
xi: reg aret3ri evsemb evsembstcpi stcpi if sample1==1, robust cluster(date)
outreg evsemb evsembstcpi stcpi using Table2, ctitle(ab3,s1,clcomp) se 3aster bdec(4) rdec(4) append
* Interact with Corruption according to Kaufman
xi: reg aret3ri evsemb evsembstcorrk stcorrk if sample1==1, robust cluster(date)
outreg evsemb evsembstcorrk stcorrk using Table2, ctitle(ab3,s1,clcomp) se 3aster bdec(4) rdec(4) append
* Interact with Transparency Index
xi: reg aret3ri evsemb evsembsttransp sttransp if sample1==1, robust cluster(date)
outreg evsemb evsembsttransp sttransp using Table2, ctitle(ab3,s1,clcomp) se 3aster bdec(4) rdec(4) append
* Interact with Press Freedom
xi: reg aret3ri evsemb evsembstpressfr stpressfr if sample1==1, robust cluster(date)
outreg evsemb evsembstpressfr stpressfr using Table2, ctitle(ab3,s1,clcomp) se 3aster bdec(4) rdec(4) append
* Interact with Bribepayer
xi: reg aret3ri evsemb evsembstbpi06 stbpi06 if sample1==1, robust cluster(date)
outreg using Table2, ctitle(ab3,s1,clcomp) se 3aster bdec(4) rdec(4) append
* Interact with Shleifer Index
xi: reg aret3ri evsemb evsembstnodeal stnodeal if sample1==1, robust cluster(date)
outreg evsemb evsembstnodeal stnodeal using Table2, ctitle(ab3,s1,clcomp) se 3aster bdec(4) rdec(4) append


******** TABLE 3 -- EVENT SELECTION TABLE
* Do with standard event definition
xi: reg aret3ri evsemb evsembd2cpi d2cpi if sample1==1, robust cluster(date)
outreg evsemb evsembd2cpi d2cpi using Table3, title(Table on Event Selection) ctitle(ab3,s1,clcomp) se 3aster bdec(4) rdec(4) replace
* Do with weak event definition
xi: reg aret3ri evlemb evlembd2cpi d2cpi if sample1==1, robust cluster(date)
outreg evlemb evlembd2cpi d2cpi using Table3, ctitle(ab3,s1,clcomp) se 3aster bdec(4) rdec(4) append
* Do with both event definitions
xi: reg aret3ri evsemb evsembd2cpi evlemb evlembd2cpi d2cpi if sample1==1, robust cluster(date)
outreg evsemb evsembd2cpi evlemb evlembd2cpi d2cpi using Table3, ctitle(ab3,s1,clcomp) se 3aster bdec(4) rdec(4) append
* Do with "automated" event definition -- s2
xi: reg aret3ri evs2emb evs2embd2cpi d2cpi if sample1==1, robust cluster(date)
outreg evs2emb evs2embd2cpi d2cpi using Table3, ctitle(ab3,s1,clcomp) se 3aster bdec(4) rdec(4) append
* Do with "automated" event definition -- s3
xi: reg aret3ri evs3emb evs3embd2cpi d2cpi if sample1==1, robust cluster(date)
outreg evs3emb evs3embd2cpi d2cpi using Table3, ctitle(ab3,s1,clcomp) se 3aster bdec(4) rdec(4) append


******** TABLE 4 -- BY TYPE OF ARMS BEING TRADED
* Table with small and large companies
xi: reg aret3ri evsemb evsembd2cpi d2cpi if sample1==1 & drevq1==1, robust cluster(date)
outreg using Table4, ctitle(revq1,s1,clcomp) se 3aster bdec(4) rdec(4) replace
xi: reg aret3ri evsemb evsembd2cpi d2cpi if sample1==1 & drevq1==0, robust cluster(date)
outreg using Table4, ctitle(norevq1,s1,clcomp) se 3aster bdec(4) rdec(4) append
* By type of arms
xi: reg aret3ri evsemb evsembd2cpi d2cpi if sampleamms==1, robust cluster(date)
outreg using Table4, ctitle(amms,s1,clcomp) se 3aster bdec(4) rdec(4) append
xi: reg aret3ri evsemb evsembd2cpi d2cpi if samplemisss==1, robust cluster(date)
outreg using Table4, ctitle(misss,s1,clcomp) se 3aster bdec(4) rdec(4) append
xi: reg aret3ri evsemb evsembd2cpi d2cpi if sampletanks==1, robust cluster(date)
outreg using Table4, ctitle(tanks,s1,clcomp) se 3aster bdec(4) rdec(4) append
xi: reg aret3ri evsemb evsembd2cpi d2cpi if sampleexps==1, robust cluster(date)
outreg using Table4, ctitle(exps,s1,clcomp) se 3aster bdec(4) rdec(4) append


******** TABLE 5 -- EVENTS IN NON-EMBARGO PERIODS
* Table NoEmb -- Results outside embargo
xi: reg aret3ri evsemb evsnoemb evsnenoemb evsembd2cpi evsembd2transp evsnoembd2cpi evsnoembd2transp evsnenoembd2cpi evsnenoembd2transp d2cpi d2transp if sample1==1, robust cluster(date)
outreg evsemb evsembd2cpi evsembd2transp evsnoemb evsnoembd2cpi evsnoembd2transp evsnenoemb evsnenoembd2cpi evsnenoembd2transp using Table5, title(Table NoEmb) ctitle(First) se 3aster bdec(4) rdec(4) replace
* Basic spec
xi: reg aret3ri evsemb evsnoemb evsnenoemb if sample1==1, robust cluster(date)
outreg using Table5, ctitle(ab3,s1,clcomp) se 3aster bdec(4) rdec(4) append
* Interact with Corruption Index
xi: reg aret3ri evsemb evsembd2cpi evsnoemb evsnoembd2cpi evsnenoemb evsnenoembd2cpi d2cpi if sample1==1, robust cluster(date)
outreg evsemb evsembd2cpi evsnoemb evsnoembd2cpi evsnenoemb evsnenoembd2cpi d2cpi using Table5, ctitle(ab3,s1,clcomp) se 3aster bdec(4) rdec(4) append
* Interact with Transparency Index
xi: reg aret3ri evsemb evsembd2transp evsnoemb evsnoembd2transp evsnenoemb evsnenoembd2transp d2transp if sample1==1, robust cluster(date)
outreg evsemb evsemb evsembd2transp evsnoemb evsnoembd2transp evsnenoemb evsnenoembd2transp d2transp using Table5, ctitle(ab3,s1,clcomp) se 3aster bdec(4) rdec(4) append


******** PLACEBO TREATMENTS IN TEXT -- MARKET RETURNS
xi: reg ret3li evsemb evsembd2cpi d2cpi if sample1==1 & aret3ri~=., robust cluster(date)
outreg using TablePlaceboText, ctitle(ab3li,s1,clcomp) se 3aster bdec(4) rdec(4) replace



**** Reload the data with all leads and ags
cd ..
cd ..
clear all
set mem 450m
use regs/weaponsregsAEJ,clear
drop day month unembargo samplenowest retri retli eretri ev*s2noemb* ev*s3noemb* evsneemb* /*
*/ *usd* evs evs2 evs3 evl evsne pressfrav cpiav nodeal transp cpi pressfr bpi06 corrk /*
*/ evl*noemb* *unexplx* *implx* evs2*tr* evs3*tr* evl*tr* hits* compnamelong listing country
replace descr=abbrev(descr,12)
replace descr="" if evsemb==0
cd output/TablesAEJOct10
compress
memory

******** WEB APPENDIX TABLE 6 -- TIMING OF EFFECTS
xi: reg aretrim2 evsemb evsembd2cpi d2cpi if sample1==1 & aret3ri~=., robust cluster(date)
outreg using WebTable6, title(Table on Timing of Effects) ctitle(abm2,s1,clcomp) se 3aster bdec(4) rdec(4) replace
foreach x in "m1" "" "p1" "p2" {
	xi: reg aretri`x' evsemb evsembd2cpi d2cpi if sample1==1 & aret3ri~=., robust cluster(date)
	outreg using WebTable6, ctitle(ab`x',s1,clcomp) se 3aster bdec(4) rdec(4) append
	}


******** FIGURE 3 -- TIMING OF EFFECT
xi: reg aretri d2cpi if sample1==1 & aret3ri~=., robust cluster(date)
outreg using Figure3, title(Title on Placeboes) ctitle(ab3,s1,clcomp) se 3aster bdec(4) rdec(4) replace
*& evembm[1-15]cpi, evsembm[1-15]d2nocpi , evsembp[1-15]d2cpi, evsembp[1-15]d2nocpi
foreach x in m15 m14 m13 m12 m11 m10 m9 m8 m7 m6 m5 mB4 m3 m2 m1 p1 p2 p3 p4 p5 p6 p7 p8 p9 p10 p11 p12 p13 p14 p15 {
	gen evsemb`x'd2cpi=evsemb`x'*d2cpi
	gen evsemb`x'd2nocpi=evsemb`x'*(1-d2cpi)
	}
aorder evsemb*d2cpi 
aorder evsemb*d2nocpi
xi: reg aretri evsembd2nocpi evsembm1d2nocpi-evsembm15d2nocpi evsembp1d2nocpi-evsembp15d2nocpi evsembd2cpi evsembm1d2cpi-evsembm15d2cpi evsembp1d2cpi-evsembp15d2cpi d2cpi if sample1==1 & aret3ri~=., robust cluster(date)
outreg using Figure3, ctitle(ab15,s1,clcomp) se 3aster bdec(4) rdec(4) append
** See below to generate the Figure itself


******** FIGURE 4A AND 4B -- TEMPORAL PLACEBO
xi: reg aret3ri d2cpi if sample1==1 & aret3ri~=., robust cluster(date)
outreg using Figure4, title(Title on Placeboes) ctitle(ab3,s1,clcomp) se 3aster bdec(4) rdec(4) replace
forvalues x=3(1)200 {
	gen evsembPlac=evsembm`x'
	gen evsembPlacd2cpi=evsembm`x'*d2cpi
	xi: reg aret3ri evsembPlac evsembPlacd2cpi d2cpi if sample1==1 & aret3ri~=., robust cluster(date)
	outreg using Figure4, ctitle(ab3m`x',s1,clcomp) se 3aster bdec(4) rdec(4) append
	drop evsembPlac evsembPlacd2cpi
	}
forvalues x=3(1)200 {
	gen evsembPlac=evsembp`x'
	gen evsembPlacd2cpi=evsembp`x'*d2cpi
	xi: reg aret3ri evsembPlac evsembPlacd2cpi d2cpi if sample1==1 & aret3ri~=., robust cluster(date)
	outreg using Figure4, ctitle(ab3p`x',s1,clcomp) se 3aster bdec(4) rdec(4) append
	drop evsembPlac evsembPlacd2cpi
	}
* This is then transformed to format readable in Stata
use Figure4data, clear
* cumulative distributions
cumul coeff_l, gen(cdf_l)
label var cdf_l "CDF"
cumul coeff_h, gen(cdf_h)
label var cdf_h "CDF"
* Figure 4, Panel A. Graph placebo for low corruption
twoway scatter   cdf_l coeff_l,sort xline(-0.0042)
graph save graph_l,replace
* Figure 4, Panel B. Graph placebo for high corruption interaction term
twoway scatter   cdf_h coeff_h,sort xline(0.0115)
graph save graph_h,replace


******** FIGURE 3 -- TIMING OF EFFECT, Ctd.
* this is created by hand using the file Figure3 above
insheet using figure3_rawdata.csv, clear

keep if abs(day)<16
twoway (rarea c_low c_high day if corruption==1, color(gs13)) (rcap c_low c_high day if corruption==0, lcolor(purple) lwidth(thin) lpattern(dash)) (connected value day if corruption==0, msymbol(square) mcolor(purple) msize(vsmall) lcolor(purple) lwidth(thin)) (connected value day if corruption==1, msymbol(D) mcolor(navy) msize(vsmall) lcolor(navy) lwidth(thin)) , scheme(s2color) ysize(7) xsize(8) ylabel(-0.01(0.002)0.01, labsize(vsmall)) xlabel(-11(2)11, labsize(vsmall)) graphregion(lcolor(white) lwidth(thick) margin(3 4 0 2)) legend(lab(3 "Low-Corruption Countries") lab(4 "High-Corruption Countries") lab(1 "") lab(2 "") size(vsmall)  order(2 3 1 4) ) xtitle("Date around Event (normalized)",size(vsmall))  ytitle("Daily Return", size(vsmall)) xline(0,lcolor(red)) title("Daily Return around Conflict Events in Low-Corruption and High-Corruption Countries",size(vsmall)) 

graph export figure_3.eps,replace
shell ps2pdf figure_3.eps


